<?php
	/**
	 * Provide a admin area view for the plugin
	 *
	 * This file is used to markup the admin-facing aspects of the plugin.
	 *
	 * @link       https://www.swascan.com
	 * @since      0.9
	 *
	 * @package    GDPR-WP
	 * @subpackage GDPR-WP/admin/partials
	 */

	// check user capabilities
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}

?>
<style>
.wrap h1 {
	padding: 40px 0;
}

.wrap .logo {
	max-width: 60px;
	float: right;
}

.wrap .logo img {
	width: 100%;
	height: auto;
}

.wrap .logo:after {
	clear: both;
}

.clear {
	clear: both;
}

.postbox-container .postbox {
	background-color: #0079C5;
}

.postbox-container .postbox h2 {
	color: #fff;
}

.postbox-container .postbox .inside {
	border-top: 1px solid #fff;
	padding-top: 10px;
	color: #fff;
}

.postbox-container .postbox .inside a {
	color: #FEA92C;
}

</style>
<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?><span class="logo"><a href="https://www.swascan.com" targer="_blank"><img src="<?php echo plugin_dir_url( __FILE__ ); ?>/img/logo.png" alt="" /></a></span></h1>
	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">
			<div id="post-body-content">
				<div class="postbox">
					<div class="inside">
						<p>By submitting this form we will send a confirmation email. If confirmed, we will log this event and generate a list with the email of all users.</br>
						These emails should be added to a mailing service and used only to send the data breach notification as required by law.</br>
						On this email, you should add the same type of information you are adding to these fields.</p>
						<form class="gdpr-data-breach-email" method="post" action="">
							<?php wp_nonce_field( 'gdpr-data-breach-request', '_gdpr_wp_data_breach' ); ?>
							<table class="form-table">
								<tr>
									<th><?php esc_html_e( 'Nature of the personal data breach', 'gdpr-wp' ) ?></th>
									<td>
										<textarea name="gdpr-data-breach-nature" class="large-text" rows="5" required></textarea>
										<span class="description"><?php esc_html_e( 'Describe the nature of the personal data breach including where possible, the categories and approximate number of data subjects concerned and the categories and approximate number of personal data records concerned.', 'gdpr-wp' ) ?></span>
									</td>
								</tr>
								<tr>
									<th><?php esc_html_e( 'Name and contact details of the data protection officer', 'gdpr-wp' ) ?></th>
									<td>
										<textarea name="gdpr-name-contact-details-protection-officer" class="large-text" rows="5" required></textarea>
										<span class="description"><?php esc_html_e( 'Communicate the name and contact details of the data protection officer or other contact point where more information can be obtained.', 'gdpr-wp' ) ?></span>
									</td>
								</tr>
								<tr>
									<th><?php esc_html_e( 'Likely consequences of the personal data breach', 'gdpr-wp' ) ?></th>
									<td>
										<textarea name="gdpr-likely-consequences" class="large-text" rows="5" required></textarea>
									</td>
								</tr>
								<tr>
									<th><?php esc_html_e( 'Measures taken or proposed to be taken', 'gdpr-wp' ) ?></th>
									<td>
										<textarea name="gdpr-measures-taken" class="large-text" rows="5" required></textarea>
										<span class="description"><?php esc_html_e( 'Describe the measures taken or proposed to be taken by the controller to address the personal data breach, including, where appropriate, measures to mitigate its possible adverse effects.', 'gdpr-wp' ) ?></span>
									</td>
								</tr>
							</table>
							<span class="spinner"></span>
							<p class="response"></p>
							<?php submit_button( 'Send Confirmation Email', 'primary', '', false ); ?>
						</form>
					</div>
				</div>
				<div class="postbox gdpr-audit-log-result">
					<h2><?php echo _e( 'Result', 'gdpr-wp' ); ?></h2>
					<div class="inside">
						<textarea readonly class="gdpr-audit-log-result large-text" rows="20"></textarea>
						<button class="button-primary"><?php esc_html_e( 'Print', 'gdpr-wp' ); ?></button>
					</div>
				</div>
				<div class="postbox gdpr-audit-log-error">
					<h2><?php echo _e( 'Error', 'gdpr-wp' ); ?></h2>
					<div class="inside">
						<p><?php esc_html_e( 'We could not find a user with that email.', 'gdpr-wp' ); ?></p>
					</div>
				</div>
			</div>
			<div id="postbox-container-1" class="postbox-container">
				<div class="postbox">
					<h2>About the plugin</h2>
					<div class="inside">
						This plugin help website owners to comply with European privacy regulations (GDPR). Within May 24th, 2018 all the websites must comply with this regulation. The plugin is brought to you by <a href="https://www.swascan.com" target="_blank">Swascan</a> which provides all the tools and resources you may need to comply with the <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a> and to <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">scan your web for vulnerabilities</a>.
					</div>
				</div>
				<div class="postbox">
					<h2>Swascan Services</h2>
					<div class="inside">
						<ul>
							<li><a href="https://www.swascan.com/#gdpr-assessment" target="_blank">GDPR Assessment</a></li>
							<li><a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">Vulnerability Assessment</a></li>
							<li><a href="https://www.swascan.com/#network-scan" target="_blank">Network Scan</a></li>
						</ul>
					</div>
				</div>
				<div class="postbox">
					<h2>Warning</h2>
					<div class="inside">
						ACTIVATING THIS PLUGIN DOES NOT GUARANTEE THAT AN ORGANIZATION IS SUCCESSFULLY MEETING ITS RESPONSIBILITIES AND OBLIGATIONS OF <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a>. INDIVIDUAL ORGANIZATIONS SHOULD ASSESS THEIR UNIQUE RESPONSIBILITIES AND ENSURE EXTRA MEASURES ARE TAKE TO MEET ANY OBLIGATIONS REQUIRED BY LAW AND BASED ON A <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">DATA PROTECTION IMPACT ASSESSMENT</a> (DPIA).
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<?php
