<?php
	/**
	 * Provide a admin area view for the plugin
	 *
	 * This file is used to markup the admin-facing aspects of the plugin.
	 *
	 * @link       https://www.swascan.com
	 * @since      0.9
	 *
	 * @package    GDPR-WP
	 * @subpackage GDPR-WP/admin/partials
	 */

	// check user capabilities
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}

	$pages = get_pages();
	$options = get_option( 'gdpr_wp_options', array() );
?>
<style>
.wrap h1 {
	padding: 40px 0;
}

.wrap .logo {
	max-width: 60px;
	float: right;
}

.wrap .logo img {
	width: 100%;
	height: auto;
}

.wrap .logo:after {
	clear: both;
}

.clear {
	clear: both;
}

.postbox-container .postbox {
	background-color: #0079C5;
}

.postbox-container .postbox h2 {
	color: #fff;
}

.postbox-container .postbox .inside {
	border-top: 1px solid #fff;
	padding-top: 10px;
	color: #fff;
}

.postbox-container .postbox .inside a {
	color: #FEA92C;
}

</style>
<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?><span class="logo"><a href="https://www.swascan.com" targer="_blank"><img src="<?php echo plugin_dir_url( __FILE__ ); ?>/img/logo.png" alt="" /></a></span></h1>

	<?php if ( isset( $_GET['settings-updated'] ) ) : ?>
		<div class="notice notice-success is-dismissible"><p><?php esc_html_e( 'Settings Updated', 'gdpr-wp' ); ?></p></div>
	<?php endif; ?>
	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">
			<div id="post-body-content">
				<form method="post" action="<?php echo admin_url( 'admin.php?page=gdpr-settings&settings-updated=1' ) ?>">
					<?php wp_nonce_field( 'gdpr_wp_options_save' ); ?>
					<div class="postbox">
						<h2 class="hndle"><?php esc_html_e( 'General', 'gdpr-wp' ); ?></h2>
						<div class="inside">
							<table class="form-table">
								<tr>
									<th><?php esc_html_e( 'Privacy Policy Page', 'gdpr-wp' ) ?></th>
									<td>
										<?php $pp_page = ( isset( $options['pp-page'] ) ) ? $options['pp-page'] : ''; ?>
										<select name="gdpr_wp_options[pp-page]">
											<option value=""><?php esc_html_e( 'Select your Privacy Policy Page', 'gdpr-wp' ) ?></option>
											<?php foreach ( $pages as $page ): ?>
												<option value="<?php echo esc_attr( $page->ID ) ?>" <?php selected( $pp_page, $page->ID ); ?>><?php echo esc_html( $page->post_title ); ?></option>
											<?php endforeach; ?>
										</select>
										<span class="description"><?php esc_html_e( 'If this page is updated, you must notify users and ask for their consent again.', 'gdpr-wp' ) ?></span>
									</td>
								</tr>
								<tr>
									<th><?php esc_html_e( 'Terms of Service Page', 'gdpr-wp' ) ?></th>
									<td>
										<?php $tos_page = ( isset( $options['tos-page'] ) ) ? $options['tos-page'] : ''; ?>
										<select name="gdpr_wp_options[tos-page]">
											<option value=""><?php esc_html_e( 'Select your Terms of Service Page', 'gdpr-wp' ) ?></option>
											<?php foreach ( $pages as $page ): ?>
												<option value="<?php echo esc_attr( $page->ID ) ?>" <?php selected( $tos_page, $page->ID ); ?>><?php echo esc_html( $page->post_title ); ?></option>
											<?php endforeach; ?>
										</select>
										<span class="description"><?php esc_html_e( 'If this page is updated, you must notify users and ask for their consent again.', 'gdpr-wp' ) ?></span>
									</td>
								</tr>
								<tr>
									<th><?php esc_html_e( 'Processor Contact Information', 'gdpr-wp' ) ?></th>
									<td>
										<?php $processor_contact_info = ( isset( $options['processor-contact-info'] ) ) ? $options['processor-contact-info'] : ''; ?>
										<input type="email" class="all-options" name="gdpr_wp_options[processor-contact-info]" value="<?php echo esc_attr( $processor_contact_info ); ?>">
										<span class="description"><a href="https://gdpr-info.eu/art-28-gdpr/" target="_blank" rel="nofollow"><?php esc_html_e( 'What is this?', 'gdpr-wp' ); ?></a></span>
									</td>
								</tr>
							</table>
						</div>
					</div>
					<h3><?php esc_html_e( 'Consents', 'gdpr-wp' ); ?></h3>
					<p><?php esc_html_e( 'For every type of data you get from the user, you should have a box filled up.', 'gdpr-wp' ) ?></p>
					<p><?php esc_html_e( 'The description must be a detailed explanation of why you are getting that data, what do you want to do with it, how long will you keep it and if you are going to share that data with third parties.', 'gdpr-wp' ) ?></p>
					<?php $consents = ( isset( $options['consents'] ) ) ? $options['consents'] : array(); ?>
					<?php if ( ! empty( $consents ) ) : ?>
						<?php $i = 0; ?>
						<?php foreach ( $consents as $k => $v ) : ?>
							<div class="postbox repeater">
								<div class="inside">
									<table class="form-table">
										<tr>
											<th><?php esc_html_e( 'Consent Title', 'gdpr-wp' ) ?></th>
											<td>
												<input type="text" data-id="title" class="regular-text" value="<?php echo esc_attr( $v['title'] ) ?>" name="gdpr_wp_options[consents][<?php echo $i; ?>][title]" id="">
											</td>
										</tr>
										<tr>
											<th><?php esc_html_e( 'Unique ID', 'gdpr-wp' ) ?></th>
											<td>
												<input type="text" data-id="id" readonly class="regular-text" value="<?php echo esc_attr( $k ) ?>" name="gdpr_wp_options[consents][<?php echo $i; ?>][id]" id="">
											</td>
										</tr>
										<tr>
											<th><?php esc_html_e( 'Consent Description', 'gdpr-wp' ) ?></th>
											<td>
												<textarea class="large-text" rows="4" name="gdpr_wp_options[consents][<?php echo $i; ?>][description]"><?php echo esc_html( $v['description'] ) ?></textarea>
											</td>
										</tr>
									</table>
								</div>
							</div>
						<?php $i++; ?>
						<?php endforeach; ?>
					<?php endif; ?>
					<a href="#" class="button-primary add-another-consent"><?php esc_html_e( 'Add another consent', 'gdpr-wp' ); ?></a>
					<?php submit_button( 'Save Settings' ); ?>
				</form>
			</div>
			<div id="postbox-container-1" class="postbox-container">
				<div class="postbox">
					<h2>About the plugin</h2>
					<div class="inside">
						This plugin help website owners to comply with European privacy regulations (GDPR). Within May 24th, 2018 all the websites must comply with this regulation. The plugin is brought to you by <a href="https://www.swascan.com" target="_blank">Swascan</a> which provides all the tools and resources you may need to comply with the <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a> and to <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">scan your web for vulnerabilities</a>.
					</div>
				</div>
				<div class="postbox">
					<h2>Swascan Services</h2>
					<div class="inside">
						<ul>
							<li><a href="https://www.swascan.com/#gdpr-assessment" target="_blank">GDPR Assessment</a></li>
							<li><a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">Vulnerability Assessment</a></li>
							<li><a href="https://www.swascan.com/#network-scan" target="_blank">Network Scan</a></li>
						</ul>
					</div>
				</div>
				<div class="postbox">
					<h2>Warning</h2>
					<div class="inside">
						ACTIVATING THIS PLUGIN DOES NOT GUARANTEE THAT AN ORGANIZATION IS SUCCESSFULLY MEETING ITS RESPONSIBILITIES AND OBLIGATIONS OF <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a>. INDIVIDUAL ORGANIZATIONS SHOULD ASSESS THEIR UNIQUE RESPONSIBILITIES AND ENSURE EXTRA MEASURES ARE TAKE TO MEET ANY OBLIGATIONS REQUIRED BY LAW AND BASED ON A <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">DATA PROTECTION IMPACT ASSESSMENT</a> (DPIA).
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<?php
